@@ -94,14 +94,14 @@ class Config
     @config.sync
   end
 
-  def post_str_append
-    @config.setGroup("Write")
-    @config.readEntry("PostStrAppend", "&suka=pontan")
+  def thread_font
+    @config.setGroup("Face")
+    @config.readFontEntry("ThreadFont")
   end
 
-  def post_str_append=(str)
-    @config.setGroup("Write")
-    @config.writeEntry("PostStrAppend", str)
+  def thread_font=(font)
+    @config.setGroup("Face")
+    @config.writeEntry("ThreadFont", font)
     @config.sync
   end
 end
