@@ -23,7 +23,7 @@ class Comment
   attr_accessor :num, :name, :mail, :date, :body, :id
 
   def to_html
-    html = "<div class='res_title'><a href='#write#{num}'>#{num}</a> "
+    html = "<div class='res_title'><a name='res#{num}' href='#write#{num}'>#{num}</a> "
     if mail != nil && mail.length != 0 then
       html += "名前:<a href='mailto:#{mail}' title='#{mail}'><b>#{name}</b></a> : "
     else
@@ -35,10 +35,24 @@ class Comment
     html
   end
 
+  def to_plain
+    text = "#{num} 名前:#{Util::to_plain(name)} #{date}\n"
+    text += Util::to_plain(@body)
+
+    text
+  end
+
   def parse_body
-    @body.gsub(/h?t?tp:\/\/([-_.!~*\'()a-zA-Z0-9;\/?:\@&=+\$,%#]+)/) {|matched|
+    body = @body.gsub(/h?t?tp:\/\/([-_.!~*\'()a-zA-Z0-9;\/?:\@&=+\$,%#]+)/) {|matched|
       "<a href=\"http://#{$1}\">#{matched}</a>"
     }
+    body = body.gsub(/<a href="\.\.\/[^"]*\/([0-9]+)" target="_blank">([^<]+)<\/a>/) {|matched|
+      "<a href=\"#res#{$1}\">#{$2}</a>"
+    }
+    body = body.gsub(/<a href="\.\.\/[^"]*\/([0-9]+-[0-9]+)" target="_blank">([^<]+)<\/a>/) {|matched|
+      "<a href=\"#res#{$1}\">#{$2}</a>"
+    }
+    body
   end
 end
 
@@ -158,6 +172,11 @@ class DatInfo
   def body(num)
     @comments[num-1].body
   end
+
+  def to_plain(num)
+    if @comments[num-1] == nil then return "" end
+    @comments[num-1].to_plain
+  end
 end
 
 class DatManager
