@@ -20,9 +20,16 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 class KitaHTMLPart < KDE::HTMLPart
+  slots 'slotOnURL(const QString&)'
+
   POPUP_WRITE_RES = 0
   POPUP_WRITE_RES_WITH_QUOTE = 1
 
+  def initialize(parent)
+    super
+    connect(self, SIGNAL("onURL(const QString&)"), self, SLOT("slotOnURL(const QString&)"))
+  end
+
   def set_view(view)
     @thread_view = view
   end
@@ -43,8 +50,20 @@ class KitaHTMLPart < KDE::HTMLPart
         res = res.gsub(/(^|<br>)/, "\n> ")[1..-1]
         @thread_view.show_write_dialog_with_str(res)
       end
+    elsif url[0..3] == "#res" then
+      num = url[4..-1].to_i
+      gotoAnchor("res#{num}")
     else
       $app.invokeBrowser(url)
     end
   end
+
+  def slotOnURL(url)
+    if url && url[0..3] == "#res" then
+      num = url[4..-1].to_i
+      node = nodeUnderMouse()
+      plain = Util::to_plain(@thread_view.to_plain(num))
+      node.setTitle(DOM::DOMString.new(plain))
+    end
+  end
 end
