@@ -37,7 +37,7 @@ class MainWindow < KDE::MainWindow
     hsplit = Qt::Splitter.new(main_widget)
     main_layout.addWidget(hsplit)
 
-    @board_list_view = BoardListView.new(hsplit)
+    @board_list_widget = BoardListWidget.new(hsplit)
 
     vsplit = Qt::Splitter.new(Qt::Splitter::Vertical, hsplit)
 
@@ -62,7 +62,7 @@ class MainWindow < KDE::MainWindow
     menu_bar = menuBar()
     file_menu = Qt::PopupMenu.new(self)
     menu_bar.insertItem("&File", file_menu)
-    file_menu.insertItem("Load Board List", @board_list_view,
+    file_menu.insertItem("Load Board List", @board_list_widget,
                          SLOT("load_board_list()"))
     file_menu.insertItem("Login", self,
                          SLOT("login()"))
