@@ -27,6 +27,9 @@ class PreferenceDialog < KDE::DialogBase
 
     @general_vbox = addVBoxPage("General", nil, KDE::SmallIcon("configure", 32))
 
+    @face_vbox = addVBoxPage("外観", nil, KDE::SmallIcon("configure", 32))
+    @face_page = FacePage.new(@face_vbox)
+
     @account_vbox = addVBoxPage("Account", nil, KDE::SmallIcon("identity", 32))
     @account_page = AccountPage.new(@account_vbox)
 
@@ -40,13 +43,13 @@ class PreferenceDialog < KDE::DialogBase
 
   def load_config
     config = Config.instance
+    @face_page.thread_font_requester.setFont(config.thread_font)
     @account_page.id_line.text = config.user_id
     @account_page.password_line.text = config.password
     @account_page.autologin_check.setChecked(config.auto_login)
     @write_page.default_name_line.text = config.default_name
     @write_page.default_mail_line.text = config.default_mail
     @write_page.kotehan_edit.text = config.kotehan.join("\n")
-    @write_page.post_line.text = config.post_str_append
   end
 
   def save_config
@@ -56,15 +59,15 @@ class PreferenceDialog < KDE::DialogBase
     default_name = @write_page.default_name_line.text
     default_mail = @write_page.default_mail_line.text
     kotehan = @write_page.kotehan_edit.text.split("\n").grep(/^.+$/)
-    post_str = @write_page.post_line.text
+    thread_font = @face_page.thread_font_requester.font
 
     config = Config.instance
+    config.thread_font = thread_font
     config.user_id = id
     config.password = password
     config.auto_login = auto_login
     config.default_name = default_name
     config.default_mail = default_mail
     config.kotehan = kotehan
-    config.post_str_append = post_str
   end
 end
