@@ -129,7 +129,8 @@ class WriteDialog < WriteDialogBase
     Net::HTTP.start(URI.parse(@write_url).host, 80) {|http|
       header = {
         "Content-Type" => "application/x-www-form-urlencoded",
-        "Referer" => @board_url
+        "Referer" => @board_url,
+        "User-Agent" => USER_AGENT
       }
       response = http.post(URI.parse(@write_url).path,
                            post_str, header)
@@ -144,11 +145,24 @@ class WriteDialog < WriteDialogBase
 
     return unless response_body && response_body.match(/<!-- 2ch_X:cookie -->/)
 
+    name_cmp = "<input type=hidden name=\""
+    name_index = response_body.index(name_cmp)
+    name_end_index = response_body.index("\"", name_index + name_cmp.size)
+    name = response_body[name_index + name_cmp.size...name_end_index]
+
+    value_cmp = "value=\""
+    value_index = response_body.index(value_cmp, name_end_index)
+    value_end_index = response_body.index("\"", value_index + value_cmp.size)
+    value = response_body[value_index + value_cmp.size...value_end_index]
+
+    post_str += "&#{name}=#{value}"
+
     Net::HTTP.start(URI.parse(@write_url).host, 80) {|http|
       header = {
         "Content-Type" => "application/x-www-form-urlencoded",
         "Referer" => @board_url,
-        "Cookie" => cookies.join(";")
+        "Cookie" => cookies.join(";"),
+        "User-Agent" => USER_AGENT
       }
       response = http.post(URI.parse(@write_url).path,
                            post_str, header)
